@@ -86,7 +86,7 @@
 #define KCALENDARCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCALENDARCORE_NO_DEPRECATED
-#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
+#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KCALENDARCORE_NO_DEPRECATED_WARNINGS
 #  define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x54a00
+#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -118,5 +118,12 @@
 #define KCALENDARCORE_DEPRECATED_VERSION_5(minor, text)      KCALENDARCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCALENDARCORE_DEPRECATED_VERSION(major, minor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCALENDARCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KCALENDARCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCALENDARCORE_DEPRECATED_VERSION(major, minor, text)
+#  define KCALENDARCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCALENDARCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KCALENDARCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KCALENDARCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KCALENDARCORE_EXPORT_H */
